package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import java.util.Enumeration;

public class CertificateList extends ASN1Encodable {
   TBSCertList tbsCertList;
   AlgorithmIdentifier sigAlgId;
   DERBitString sig;

   public static CertificateList getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static CertificateList getInstance(Object obj) {
      if (obj instanceof CertificateList) {
         return (CertificateList)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new CertificateList((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public CertificateList(ASN1Sequence seq) {
      if (seq.size() == 3) {
         this.tbsCertList = TBSCertList.getInstance(seq.getObjectAt(0));
         this.sigAlgId = AlgorithmIdentifier.getInstance(seq.getObjectAt(1));
         this.sig = DERBitString.getInstance(seq.getObjectAt(2));
      } else {
         throw new IllegalArgumentException("sequence wrong size for CertificateList");
      }
   }

   public TBSCertList getTBSCertList() {
      return this.tbsCertList;
   }

   public TBSCertList.CRLEntry[] getRevokedCertificates() {
      return this.tbsCertList.getRevokedCertificates();
   }

   public Enumeration getRevokedCertificateEnumeration() {
      return this.tbsCertList.getRevokedCertificateEnumeration();
   }

   public AlgorithmIdentifier getSignatureAlgorithm() {
      return this.sigAlgId;
   }

   public DERBitString getSignature() {
      return this.sig;
   }

   public int getVersion() {
      return this.tbsCertList.getVersion();
   }

   public X509Name getIssuer() {
      return this.tbsCertList.getIssuer();
   }

   public Time getThisUpdate() {
      return this.tbsCertList.getThisUpdate();
   }

   public Time getNextUpdate() {
      return this.tbsCertList.getNextUpdate();
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.tbsCertList);
      var1.add(this.sigAlgId);
      var10000.add(this.sig);
      return new DERSequence(var1);
   }
}
